<?php

namespace Drupal\o365;

/**
 * SharepointExtensionService service gives the correct file extension.
 */
class ExtensionService {

  /**
   * Method gives the file type so that we can use the correct image.
   *
   * @param string $mimeType
   *   The mime types.
   */
  public function extensionType($mimeType) {
    $extensionType = [
      'application/acad' => 'dwg',
      'application/activewords-wordbase' => 'awb',
      'application/andrew-inset' => 'ez',
      'application/applixware' => 'aw',
      'application/arj' => 'arj',
      'application/atom+xml' => 'atom',
      'application/atomcat+xml' => 'atomcat',
      'application/atomsvc+xml' => 'atomsvc',
      'application/base64' => 'mme',
      'application/binhex' => 'hqx',
      'application/binhex4' => 'hqx',
      'application/bm' => 'bmp',
      'application/book' => 'book',
      'application/ccxml+xml' => 'ccxml',
      'application/cd' => 'cdr',
      'application/cdf' => 'cdf',
      'application/cdmi-capability' => 'cdmia',
      'application/cdmi-container' => 'cdmic',
      'application/cdmi-domain' => 'cdmid',
      'application/cdmi-object' => 'cdmio',
      'application/cdmi-queue' => 'cdmiq',
      'application/clariscad' => 'ccad',
      'application/commonground' => 'dp',
      'application/coreldra' => 'cdr',
      'application/cu-seeme' => 'cu',
      'application/davmount+xml' => 'davmount',
      'application/drafting' => 'drw',
      'application/dsptype' => 'tsp',
      'application/dssc+der' => 'dssc',
      'application/dssc+xml' => 'xdssc',
      'application/dxf' => 'dxf',
      'application/ecmascript' => 'js',
      'application/emma+xml' => 'emma',
      'application/envoy' => 'evy',
      'application/epub+zip' => 'epub',
      'application/exce' => 'xl',
      'application/excel' => 'xl',
      'application/exi' => 'exi',
      'application/font-tdpfr' => 'pfr',
      'application/fractals' => 'fif',
      'application/freeloader' => 'frl',
      'application/futuresplash' => 'spl',
      'application/gnutar' => 'tgz',
      'application/gpg-keys' => 'gpg',
      'application/groupwise' => 'vew',
      'application/hlp' => 'hlp',
      'application/hta' => 'hta',
      'application/hyperstudio' => 'stk',
      'application/i-deas' => 'unv',
      'application/iges' => 'iges',
      'application/inf' => 'inf',
      'application/ipfix' => 'ipfix',
      'application/java' => 'class',
      'application/java-archive' => 'jar',
      'application/java-byte-code' => 'class',
      'application/java-serialized-object' => 'ser',
      'application/java-vm' => 'class',
      'application/javascript' => 'js',
      'application/json' => 'json',
      'application/lha' => 'lha',
      'application/lost+xml' => 'lostxml',
      'application/lzx' => 'lzx',
      'application/mac-binary' => 'bin',
      'application/mac-binhex' => 'hqx',
      'application/mac-binhex40' => 'hqx',
      'application/mac-compactpro' => 'cpt',
      'application/macbinar' => 'bin',
      'application/macbinary' => 'bin',
      'application/mads+xml' => 'mads',
      'application/marc' => 'mrc',
      'application/marcxml+xml' => 'mrcx',
      'application/mathematica' => 'ma',
      'application/mathml+xml' => 'mathml',
      'application/mbedlet' => 'mbd',
      'application/mbox' => 'mbox',
      'application/mcad' => 'mcd',
      'application/mediaservercontrol+xml' => 'mscml',
      'application/metalink4+xml' => 'meta4',
      'application/mets+xml' => 'mets',
      'application/mime' => 'aps',
      'application/mods+xml' => 'mods',
      'application/mp21' => 'm21',
      'application/mp4' => 'mp4s',
      'application/msaccess' => 'accdb',
      'application/msexcel' => 'xls',
      'application/mspowerpoint' => 'pot',
      'application/msword' => 'doc',
      'application/mswrite' => 'wri',
      'application/mxf' => 'mxf',
      'application/netmc' => 'mcp',
      'application/octet-stream' => 'php',
      'application/od' => 'oda',
      'application/oda' => 'oda',
      'application/oebps-package+xml' => 'opf',
      'application/og' => 'ogg',
      'application/ogg' => 'ogx',
      'application/onenote' => 'onepkg',
      'application/patch-ops-error+xml' => 'xer',
      'application/pd' => 'pdf',
      'application/pdf' => 'pdf',
      'application/pg' => 'pgp',
      'application/pgp-encrypted' => 'pgp',
      'application/pgp-signature' => 'asc',
      'application/ph' => 'php',
      'application/pics-rules' => 'prf',
      'application/pkcs-12' => 'p12',
      'application/pkcs10' => 'p10',
      'application/pkcs7-mime' => 'p7c',
      'application/pkcs7-signatur' => 'p7s',
      'application/pkcs7-signature' => 'p7s',
      'application/pkcs8' => 'p8',
      'application/pkix-attr-cert' => 'ac',
      'application/pkix-cer' => 'crt',
      'application/pkix-cert' => 'crt',
      'application/pkix-crl' => 'crl',
      'application/pkix-pkipath' => 'pkipath',
      'application/pkixcmp' => 'pki',
      'application/plain' => 'text',
      'application/pls+xml' => 'pls',
      'application/postscript' => 'ai',
      'application/powerpoint' => 'ppt',
      'application/prscww' => 'cww',
      'application/pskc+xml' => 'pskcxml',
      'application/ra' => 'rar',
      'application/rdf+xml' => 'rdf',
      'application/reginfo+xml' => 'rif',
      'application/relax-ng-compact-syntax' => 'rnc',
      'application/resource-lists-diff+xml' => 'rld',
      'application/resource-lists+xml' => 'rl',
      'application/ringing-tones' => 'rng',
      'application/rls-services+xml' => 'rs',
      'application/rsd+xml' => 'rsd',
      'application/rss+xml' => 'rss',
      'application/rtf' => 'rtf',
      'application/s-compressed' => 'zip',
      'application/sbml+xml' => 'sbml',
      'application/scvp-cv-request' => 'scq',
      'application/scvp-cv-response' => 'scs',
      'application/scvp-vp-request' => 'spq',
      'application/scvp-vp-response' => 'spp',
      'application/sdp' => 'sdp',
      'application/sea' => 'sea',
      'application/set' => 'set',
      'application/set-payment-initiation' => 'setpay',
      'application/set-registration-initiation' => 'setreg',
      'application/shf+xml' => 'shf',
      'application/sla' => 'stl',
      'application/smil' => 'smil',
      'application/smil+xml' => 'smil',
      'application/solids' => 'sol',
      'application/sounder' => 'sdr',
      'application/sparql-query' => 'rq',
      'application/sparql-results+xml' => 'srx',
      'application/srgs' => 'gram',
      'application/srgs+xml' => 'grxml',
      'application/sru+xml' => 'sru',
      'application/ssml+xml' => 'ssml',
      'application/step' => 'stp',
      'application/streamingmedia' => 'ssm',
      'application/thraud+xml' => 'tfi',
      'application/timestamped-data' => 'tsd',
      'application/toolbook' => 'tbk',
      'application/vda' => 'vda',
      'application/videolan' => 'vlc',
      'application/vnd.google-earth.kml+xml' => 'kml',
      'application/vnd.google-earth.kmz' => 'kmz',
      'application/vnd.mi' => 'mif',
      'application/vnd.mpegur' => 'm4u',
      'application/vnd.ms-excel' => 'xlsx',
      'application/vnd.ms-offic' => 'ppt',
      'application/vnd.ms-powerpoint' => 'ppt',
      'application/vnd.msexcel' => 'csv',
      'application/vnd.openxmlformats-officedocument.presentationml.presentation' => 'pptx',
      'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' => 'xlsx',
      'application/vnd.openxmlformats-officedocument.wordprocessingml.document' => 'docx',
      'application/vnd.rn-realmedia' => 'rm',
      'application/vnd3gpp2tcap' => 'tcap',
      'application/vnd3gpppic-bw-large' => 'plb',
      'application/vnd3gpppic-bw-small' => 'psb',
      'application/vnd3gpppic-bw-var' => 'pvb',
      'application/vnd3mpost-it-notes' => 'pwn',
      'application/vndaccpacsimplyaso' => 'aso',
      'application/vndaccpacsimplyimp' => 'imp',
      'application/vndacucobol' => 'acu',
      'application/vndadobeair-application-installer-package+zip' => 'air',
      'application/vndadobefxp' => 'fxp',
      'application/vndadobexdp+xml' => 'xdp',
      'application/vndadobexfdf' => 'xfdf',
      'application/vndaheadspace' => 'ahead',
      'application/vndairzipfilesecureazf' => 'azf',
      'application/vndairzipfilesecureazs' => 'azs',
      'application/vndamazonebook' => 'azw',
      'application/vndamericandynamicsacc' => 'acc',
      'application/vndamigaami' => 'ami',
      'application/vndandroidpackage-archive' => 'apk',
      'application/vndanser-web-certificate-issue-initiation' => 'cii',
      'application/vndanser-web-funds-transfer-initiation' => 'fti',
      'application/vndantixgame-component' => 'atx',
      'application/vndappleinstaller+xml' => 'mpkg',
      'application/vndapplempegurl' => 'm3u8',
      'application/vndaristanetworksswi' => 'swi',
      'application/vndaudiograph' => 'aep',
      'application/vndblueicemultipass' => 'mpm',
      'application/vndbmi' => 'bmi',
      'application/vndbusinessobjects' => 'repf',
      'application/vndchemdraw+xml' => 'cdxml',
      'application/vndchipnutskaraoke-mmd' => 'mmd',
      'application/vndcinderella' => 'cdy',
      'application/vndclaymore' => 'cla',
      'application/vndcloantorp9' => 'rp9',
      'application/vndclonkc4group' => 'c4g',
      'application/vndcluetrustcartomobile-config' => 'c11amc',
      'application/vndcluetrustcartomobile-config-pkg' => 'c11amz',
      'application/vndcommonspace' => 'csp',
      'application/vndcontactcmsg' => 'cdbcmsg',
      'application/vndcosmocaller' => 'cmc',
      'application/vndcrickclicker' => 'clkx',
      'application/vndcrickclickerkeyboard' => 'clkk',
      'application/vndcrickclickerpalette' => 'clkp',
      'application/vndcrickclickertemplate' => 'clkt',
      'application/vndcrickclickerwordbank' => 'clkw',
      'application/vndcriticaltoolswbs+xml' => 'wbs',
      'application/vndctc-posml' => 'pml',
      'application/vndcups-ppd' => 'ppd',
      'application/vndcurlcar' => 'car',
      'application/vndcurlpcurl' => 'pcurl',
      'application/vnddata-visionrdz' => 'rdz',
      'application/vnddecedata' => 'uvf',
      'application/vnddecettml+xml' => 'uvt',
      'application/vnddeceunspecified' => 'uvx',
      'application/vnddenovofcselayout-link' => 'fe_launch',
      'application/vnddna' => 'dna',
      'application/vnddolbymlp' => 'mlp',
      'application/vnddpgraph' => 'dpg',
      'application/vnddreamfactory' => 'dfac',
      'application/vnddvbait' => 'ait',
      'application/vnddvbservice' => 'svc',
      'application/vnddynageo' => 'geo',
      'application/vndecowinchart' => 'mag',
      'application/vndenliven' => 'nml',
      'application/vndepsonesf' => 'esf',
      'application/vndepsonmsf' => 'msf',
      'application/vndepsonquickanime' => 'qam',
      'application/vndepsonsalt' => 'slt',
      'application/vndepsonssf' => 'ssf',
      'application/vndeszigno3+xml' => 'es3',
      'application/vndezpix-album' => 'ez2',
      'application/vndezpix-package' => 'ez3',
      'application/vndfdf' => 'fdf',
      'application/vndfdsnmseed' => 'mseed',
      'application/vndfdsnseed' => 'seed',
      'application/vndflographit' => 'gph',
      'application/vndfluxtimeclip' => 'ftc',
      'application/vndframemaker' => 'fm',
      'application/vndfrogansfnc' => 'fnc',
      'application/vndfrogansltf' => 'ltf',
      'application/vndfscweblaunch' => 'fsc',
      'application/vndfujitsuoasys' => 'oas',
      'application/vndfujitsuoasys2' => 'oa2',
      'application/vndfujitsuoasys3' => 'oa3',
      'application/vndfujitsuoasysgp' => 'fg5',
      'application/vndfujitsuoasysprs' => 'bh2',
      'application/vndfujixeroxddd' => 'ddd',
      'application/vndfujixeroxdocuworks' => 'xdw',
      'application/vndfujixeroxdocuworksbinder' => 'xbd',
      'application/vndfuzzysheet' => 'fzs',
      'application/vndgenomatixtuxedo' => 'txd',
      'application/vndgeogebrafile' => 'ggb',
      'application/vndgeogebratool' => 'ggt',
      'application/vndgeometry-explorer' => 'gex',
      'application/vndgeonext' => 'gxt',
      'application/vndgeoplan' => 'g2w',
      'application/vndgeospace' => 'g3w',
      'application/vndgmx' => 'gmx',
      'application/vndgoogle-earthkml+xml' => 'kml',
      'application/vndgoogle-earthkmz' => 'kmz',
      'application/vndgrafeq' => 'gqf',
      'application/vndgroove-account' => 'gac',
      'application/vndgroove-help' => 'ghf',
      'application/vndgroove-identity-message' => 'gim',
      'application/vndgroove-injector' => 'grv',
      'application/vndgroove-tool-message' => 'gtm',
      'application/vndgroove-tool-template' => 'tpl',
      'application/vndgroove-vcard' => 'vcg',
      'application/vndhal+xml' => 'hal',
      'application/vndhandheld-entertainment+xml' => 'zmm',
      'application/vndhbci' => 'hbci',
      'application/vndhhelesson-player' => 'les',
      'application/vndhp-hpid' => 'hpid',
      'application/vndhp-hps' => 'hps',
      'application/vndhp-jlyt' => 'jlt',
      'application/vndhp-pcl' => 'pcl',
      'application/vndhp-pclxl' => 'pclxl',
      'application/vndhydrostatixsof-data' => 'sfd-hdstx',
      'application/vndhzn-3d-crossword' => 'x3d',
      'application/vndibmminipay' => 'mpy',
      'application/vndibmmodcap' => 'afp',
      'application/vndibmrights-management' => 'irm',
      'application/vndibmsecure-container' => 'sc',
      'application/vndiccprofile' => 'icc',
      'application/vndigloader' => 'igl',
      'application/vndimmervision-ivp' => 'ivp',
      'application/vndimmervision-ivu' => 'ivu',
      'application/vndinsorsigm' => 'igm',
      'application/vndinterconformnet' => 'xpw xpx',
      'application/vndintergeo' => 'i2g',
      'application/vndintuqbo' => 'qbo',
      'application/vndintuqfx' => 'qfx',
      'application/vndipunpluggedrcprofile' => 'rcprofile',
      'application/vndirepositorypackage+xml' => 'irp',
      'application/vndis-xpr' => 'xpr',
      'application/vndisacfcs' => 'fcs',
      'application/vndjam' => 'jam',
      'application/vndjcpjavamemidlet-rms' => 'rms',
      'application/vndjisp' => 'jisp',
      'application/vndjoostjoda-archive' => 'joda',
      'application/vndkahootz' => 'ktz',
      'application/vndkdekarbon' => 'karbon',
      'application/vndkdekchart' => 'chrt',
      'application/vndkdekformula' => 'kfo',
      'application/vndkdekivio' => 'flw',
      'application/vndkdekontour' => 'kon',
      'application/vndkdekpresenter' => 'kpr',
      'application/vndkdekspread' => 'ksp',
      'application/vndkdekword' => 'kwd',
      'application/vndkenameaapp' => 'htke',
      'application/vndkidspiration' => 'kia',
      'application/vndkinar' => 'kne',
      'application/vndkoan' => 'skp',
      'application/vndkodak-descriptor' => 'sse',
      'application/vndlaslas+xml' => 'lasxml',
      'application/vndllamagraphicslife-balancedesktop' => 'lbd',
      'application/vndllamagraphicslife-balanceexchange+xml' => 'lbe',
      'application/vndlotus-1-2-3' => '123',
      'application/vndlotus-approach' => 'apr',
      'application/vndlotus-freelance' => 'pre',
      'application/vndlotus-notes' => 'nsf',
      'application/vndlotus-organizer' => 'org',
      'application/vndlotus-screencam' => 'scm',
      'application/vndlotus-wordpro' => 'lwp',
      'application/vndmacportsportpkg' => 'portpkg',
      'application/vndmcd' => 'mcd',
      'application/vndmedcalcdata' => 'mc1',
      'application/vndmediastationcdkey' => 'cdkey',
      'application/vndmfer' => 'mwf',
      'application/vndmfmp' => 'mfm',
      'application/vndmicrografxflo' => 'flo',
      'application/vndmicrografxigx' => 'igx',
      'application/vndmif' => 'mif',
      'application/vndmobiusdaf' => 'daf',
      'application/vndmobiusdis' => 'dis',
      'application/vndmobiusmbk' => 'mbk',
      'application/vndmobiusmqy' => 'mqy',
      'application/vndmobiusmsl' => 'msl',
      'application/vndmobiusplc' => 'plc',
      'application/vndmobiustxf' => 'txf',
      'application/vndmophunapplication' => 'mpn',
      'application/vndmophuncertificate' => 'mpc',
      'application/vndmozillaxul+xml' => 'xul',
      'application/vndms-artgalry' => 'cil',
      'application/vndms-cab-compressed' => 'cab',
      'application/vndms-excel' => 'xls',
      'application/vndms-exceladdinmacroenabled12' => 'xlam',
      'application/vndms-excelsheetbinarymacroenabled12' => 'xlsb',
      'application/vndms-excelsheetmacroenabled12' => 'xlsm',
      'application/vndms-exceltemplatemacroenabled12' => 'xltm',
      'application/vndms-fontobject' => 'eot',
      'application/vndms-htmlhelp' => 'chm',
      'application/vndms-ims' => 'ims',
      'application/vndms-lrm' => 'lrm',
      'application/vndms-officetheme' => 'thmx',
      'application/vndms-pkicertstore' => 'sst',
      'application/vndms-pkipko' => 'pko',
      'application/vndms-pkiseccat' => 'cat',
      'application/vndms-pkistl' => 'stl',
      'application/vndms-powerpoint' => 'pot',
      'application/vndms-powerpointaddinmacroenabled12' => 'ppam',
      'application/vndms-powerpointpresentationmacroenabled12' => 'pptm',
      'application/vndms-powerpointslidemacroenabled12' => 'sldm',
      'application/vndms-powerpointslideshowmacroenabled12' => 'ppsm',
      'application/vndms-powerpointtemplatemacroenabled12' => 'potm',
      'application/vndms-project' => 'mpp',
      'application/vndms-worddocumentmacroenabled12' => 'docm',
      'application/vndms-wordtemplatemacroenabled12' => 'dotm',
      'application/vndms-works' => 'wps',
      'application/vndms-wpl' => 'wpl',
      'application/vndms-xpsdocument' => 'xps',
      'application/vndmseq' => 'mseq',
      'application/vndmusician' => 'mus',
      'application/vndmuveestyle' => 'msty',
      'application/vndneurolanguagenlu' => 'nlu',
      'application/vndnoblenet-directory' => 'nnd',
      'application/vndnoblenet-sealer' => 'nns',
      'application/vndnoblenet-web' => 'nnw',
      'application/vndnokiaconfiguration-message' => 'ncm',
      'application/vndnokian-gagedata' => 'ngdat',
      'application/vndnokian-gagesymbianinstall' => 'n-gage',
      'application/vndnokiaradio-preset' => 'rpst',
      'application/vndnokiaradio-presets' => 'rpss',
      'application/vndnokiaringing-tone' => 'rng',
      'application/vndnovadigmedm' => 'edm',
      'application/vndnovadigmedx' => 'edx',
      'application/vndnovadigmext' => 'ext',
      'application/vndoasisopendocumentchart' => 'odc',
      'application/vndoasisopendocumentchart-template' => 'otc',
      'application/vndoasisopendocumentdatabase' => 'odb',
      'application/vndoasisopendocumentformula' => 'odf',
      'application/vndoasisopendocumentformula-template' => 'odft',
      'application/vndoasisopendocumentgraphics' => 'odg',
      'application/vndoasisopendocumentgraphics-template' => 'otg',
      'application/vndoasisopendocumentimage' => 'odi',
      'application/vndoasisopendocumentimage-template' => 'oti',
      'application/vndoasisopendocumentpresentation' => 'odp',
      'application/vndoasisopendocumentpresentation-template' => 'otp',
      'application/vndoasisopendocumentspreadsheet' => 'ods',
      'application/vndoasisopendocumentspreadsheet-template' => 'ots',
      'application/vndoasisopendocumenttext' => 'odt',
      'application/vndoasisopendocumenttext-master' => 'odm',
      'application/vndoasisopendocumenttext-template' => 'ott',
      'application/vndoasisopendocumenttext-web' => 'oth',
      'application/vndolpc-sugar' => 'xo',
      'application/vndomadd2+xml' => 'dd2',
      'application/vndopenofficeorgextension' => 'oxt',
      'application/vndopenxmlformats-officedocumentpresentationmlpresentation' => 'pptx',
      'application/vndopenxmlformats-officedocumentpresentationmlslide' => 'sldx',
      'application/vndopenxmlformats-officedocumentpresentationmlslideshow' => 'ppsx',
      'application/vndopenxmlformats-officedocumentpresentationmltemplate' => 'potx',
      'application/vndopenxmlformats-officedocumentspreadsheetmlsheet' => 'xlsx',
      'application/vndopenxmlformats-officedocumentspreadsheetmltemplate' => 'xltx',
      'application/vndopenxmlformats-officedocumentwordprocessingmldocument' => 'docx',
      'application/vndopenxmlformats-officedocumentwordprocessingmltemplate' => 'dotx',
      'application/vndosgeomapguidepackage' => 'mgp',
      'application/vndosgidp' => 'dp',
      'application/vndpalm' => 'pdb',
      'application/vndpawaafile' => 'paw',
      'application/vndpgformat' => 'str',
      'application/vndpgosasli' => 'ei6',
      'application/vndpicsel' => 'efif',
      'application/vndpmiwidget' => 'wg',
      'application/vndpocketlearn' => 'plf',
      'application/vndpowerbuilder6' => 'pbd',
      'application/vndpreviewsystemsbox' => 'box',
      'application/vndproteusmagazine' => 'mgz',
      'application/vndpublishare-delta-tree' => 'qps',
      'application/vndpviptid1' => 'ptid',
      'application/vndquarkquarkxpress' => 'qxd',
      'application/vndrealvncbed' => 'bed',
      'application/vndrecordaremusicxml' => 'mxl',
      'application/vndrecordaremusicxml+xml' => 'musicxml',
      'application/vndrigcryptonote' => 'cryptonote',
      'application/vndrimcod' => 'cod',
      'application/vndrn-realmedia' => 'rm',
      'application/vndrn-realplayer' => 'rnx',
      'application/vndroute66link66+xml' => 'link66',
      'application/vndsailingtrackertrack' => 'st',
      'application/vndseemail' => 'see',
      'application/vndsema' => 'sema',
      'application/vndsemd' => 'semd',
      'application/vndsemf' => 'semf',
      'application/vndshanainformedformdata' => 'ifm',
      'application/vndshanainformedformtemplate' => 'itp',
      'application/vndshanainformedinterchange' => 'iif',
      'application/vndshanainformedpackage' => 'ipk',
      'application/vndsimtech-mindmapper' => 'twd',
      'application/vndsmaf' => 'mmf',
      'application/vndsmartteacher' => 'teacher',
      'application/vndsolentsdkm+xml' => 'sdkm',
      'application/vndspotfiredxp' => 'dxp',
      'application/vndspotfiresfs' => 'sfs',
      'application/vndstardivisioncalc' => 'sdc',
      'application/vndstardivisiondraw' => 'sda',
      'application/vndstardivisionimpress' => 'sdd',
      'application/vndstardivisionmath' => 'smf',
      'application/vndstardivisionwriter' => 'sdw',
      'application/vndstardivisionwriter-global' => 'sgl',
      'application/vndstepmaniastepchart' => 'sm',
      'application/vndsunxmlcalc' => 'sxc',
      'application/vndsunxmlcalctemplate' => 'stc',
      'application/vndsunxmldraw' => 'sxd',
      'application/vndsunxmldrawtemplate' => 'std',
      'application/vndsunxmlimpress' => 'sxi',
      'application/vndsunxmlimpresstemplate' => 'sti',
      'application/vndsunxmlmath' => 'sxm',
      'application/vndsunxmlwriter' => 'sxw',
      'application/vndsunxmlwriterglobal' => 'sxg',
      'application/vndsunxmlwritertemplate' => 'stw',
      'application/vndsus-calendar' => 'sus',
      'application/vndsvd' => 'svd',
      'application/vndsymbianinstall' => 'sis',
      'application/vndsyncml+xml' => 'xsm',
      'application/vndsyncmldm+wbxml' => 'bdm',
      'application/vndsyncmldm+xml' => 'xdm',
      'application/vndtaointent-module-archive' => 'tao',
      'application/vndtmobile-livetv' => 'tmo',
      'application/vndtridtpt' => 'tpt',
      'application/vndtriscapemxs' => 'mxs',
      'application/vndtrueapp' => 'tra',
      'application/vndufdl' => 'ufd',
      'application/vnduiqtheme' => 'utz',
      'application/vndumajin' => 'umj',
      'application/vndunity' => 'unityweb',
      'application/vnduoml+xml' => 'uoml',
      'application/vndvcx' => 'vcx',
      'application/vndvisio' => 'vsd',
      'application/vndvisionary' => 'vis',
      'application/vndvsf' => 'vsf',
      'application/vndwapwbxml' => 'wbxml',
      'application/vndwapwmlc' => 'wmlc',
      'application/vndwapwmlscriptc' => 'wmlsc',
      'application/vndwebturbo' => 'wtb',
      'application/vndwolframplayer' => 'nbp',
      'application/vndwordperfect' => 'wpd',
      'application/vndwqd' => 'wqd',
      'application/vndwtstf' => 'stf',
      'application/vndxara' => 'web',
      'application/vndxfdl' => 'xfdl',
      'application/vndyamahahv-dic' => 'hvd',
      'application/vndyamahahv-script' => 'hvs',
      'application/vndyamahahv-voice' => 'hvp',
      'application/vndyamahaopenscoreformat' => 'osf',
      'application/vndyamahaopenscoreformatosfpvg+xml' => 'osfpvg',
      'application/vndyamahasmaf-audio' => 'saf',
      'application/vndyamahasmaf-phrase' => 'spf',
      'application/vndyellowriver-custom-menu' => 'cmp',
      'application/vndzul' => 'zir',
      'application/vndzzazzdeck+xml' => 'zaz',
      'application/vocaltec-media-desc' => 'vmd',
      'application/vocaltec-media-file' => 'vmf',
      'application/voicexml+xml' => 'vxml',
      'application/wbxm' => 'wbxml',
      'application/widget' => 'wgt',
      'application/winhlp' => 'hlp',
      'application/wmlc' => 'wmlc',
      'application/wordperfect' => 'wp',
      'application/wordperfect61' => 'w61',
      'application/wsdl+xml' => 'wsdl',
      'application/wspolicy+xml' => 'wspolicy',
      'application/x-123' => 'wk1',
      'application/x-7z-compressed' => '7z',
      'application/x-abiword' => 'abw',
      'application/x-ace-compressed' => 'ace',
      'application/x-aim' => 'aim',
      'application/x-ape' => 'ape',
      'application/x-authorware-bin' => 'aab',
      'application/x-authorware-map' => 'aam',
      'application/x-authorware-seg' => 'aas',
      'application/x-bcpio' => 'bcpio',
      'application/x-binary' => 'bin',
      'application/x-binhex40' => 'hqx',
      'application/x-bittorrent' => 'torrent',
      'application/x-bm' => 'bmp',
      'application/x-bsh' => 'bsh',
      'application/x-bytecodeelisp (compiled elisp)' => 'elc',
      'application/x-bytecodepython' => 'pyc',
      'application/x-bzip' => 'bz',
      'application/x-cd' => 'cdr',
      'application/x-cdf' => 'cdf',
      'application/x-cdlink' => 'vcd',
      'application/x-chess-pgn' => 'pgn',
      'application/x-cmu-raster' => 'ras',
      'application/x-cocoa' => 'cco',
      'application/x-compactpro' => 'cpt',
      'application/x-compress' => 'z',
      'application/x-compressed' => '7zip',
      'application/x-conference' => 'nsc',
      'application/x-coreldra' => 'cdr',
      'application/x-cpio' => 'cpio',
      'application/x-cpt' => 'cpt',
      'application/x-csh' => 'csh',
      'application/x-debian-package' => 'deb',
      'application/x-deepv' => 'deepv',
      'application/x-director' => 'dcr',
      'application/x-director' => 'dcr',
      'application/x-doom' => 'wad',
      'application/x-dos_ms_excel' => 'xls',
      'application/x-dtbncx+xml' => 'ncx',
      'application/x-dtbook+xml' => 'dtb',
      'application/x-dtbresource+xml' => 'res',
      'application/x-dv' => 'dvi',
      'application/x-dvi' => 'dvi',
      'application/x-elc' => 'elc',
      'application/x-envoy' => 'env',
      'application/x-esrehber' => 'es',
      'application/x-excel' => 'xls',
      'application/x-font-bdf' => 'bdf',
      'application/x-font-ghostscript' => 'gsf',
      'application/x-font-linux-psf' => 'psf',
      'application/x-font-otf' => 'otf',
      'application/x-font-pcf' => 'pcf',
      'application/x-font-snf' => 'snf',
      'application/x-font-ttf' => 'ttf',
      'application/x-font-type1' => 'pfa',
      'application/x-font-woff' => 'woff',
      'application/x-frame' => 'mif',
      'application/x-freelance' => 'pre',
      'application/x-futuresplash' => 'spl',
      'application/x-gnumeric' => 'gnumeric',
      'application/x-gsp' => 'gsp',
      'application/x-gss' => 'gss',
      'application/x-gtar' => 'gtar',
      'application/x-gzip' => 'gzip',
      'application/x-gzip-compresse' => 'tgz',
      'application/x-hdf' => 'hdf',
      'application/x-httpd-imap' => 'imap',
      'application/x-httpd-ph' => 'php',
      'application/x-httpd-php-source' => 'php',
      'application/x-ima' => 'ima',
      'application/x-internett-signup' => 'ins',
      'application/x-inventor' => 'iv',
      'application/x-ip2' => 'ip',
      'application/x-ja' => 'jar',
      'application/x-java-application' => 'jar',
      'application/x-java-class' => 'class',
      'application/x-java-commerce' => 'jcm',
      'application/x-java-jnlp-file' => 'jnlp',
      'application/x-javascript' => 'js',
      'application/x-koan' => 'skp',
      'application/x-ksh' => 'ksh',
      'application/x-latex' => 'ltx',
      'application/x-lha' => 'lha',
      'application/x-lisp' => 'lsp',
      'application/x-livescreen' => 'ivy',
      'application/x-lotus' => 'wq1',
      'application/x-lotusscreencam' => 'scm',
      'application/x-lzh' => 'lzh',
      'application/x-lzx' => 'lzx',
      'application/x-mac-binhex40' => 'hqx',
      'application/x-macbinar' => 'bin',
      'application/x-macbinary' => 'bin',
      'application/x-magic-cap-package-10' => 'mc$',
      'application/x-mathcad' => 'mcd',
      'application/x-meme' => 'mm',
      'application/x-midi' => 'mid',
      'application/x-mif' => 'mif',
      'application/x-mix-transfer' => 'nix',
      'application/x-mobipocket-ebook' => 'prc',
      'application/x-mplayer2' => 'asx',
      'application/x-ms-application' => 'application',
      'application/x-ms-excel' => 'xls',
      'application/x-ms-wmd' => 'wmd',
      'application/x-ms-wmz' => 'wmz',
      'application/x-ms-xbap' => 'xbap',
      'application/x-msaccess' => 'mdb',
      'application/x-msbinder' => 'obd',
      'application/x-mscardfile' => 'crd',
      'application/x-msclip' => 'clp',
      'application/x-msdownload' => 'exe',
      'application/x-msdownload' => 'exe',
      'application/x-msexce' => 'xls',
      'application/x-msexcel' => 'xls',
      'application/x-msmediaview' => 'mvb',
      'application/x-msmetafile' => 'wmf',
      'application/x-msmoney' => 'mny',
      'application/x-mspowerpoint' => 'ppt',
      'application/x-mspublisher' => 'pub',
      'application/x-msschedule' => 'scd',
      'application/x-msterminal' => 'trm',
      'application/x-mswrite' => 'wri',
      'application/x-navi-animation' => 'ani',
      'application/x-navidoc' => 'nvd',
      'application/x-navimap' => 'map',
      'application/x-navistyle' => 'stl',
      'application/x-newton-compatible-pkg' => 'pkg',
      'application/x-nokia-9000-communicator-add-on-software' => 'aos',
      'application/x-omc' => 'omc',
      'application/x-omcdatamaker' => 'omcd',
      'application/x-omcregerator' => 'omcr',
      'application/x-pagemaker' => 'pm',
      'application/x-pcl' => 'pcl',
      'application/x-pem-file' => 'pem',
      'application/x-ph' => 'php',
      'application/x-photosho' => 'psd',
      'application/x-pixclscript' => 'plx',
      'application/x-pkcs' => 'rsa',
      'application/x-pkcs10' => 'p10',
      'application/x-pkcs12' => 'p12',
      'application/x-pkcs7-certificates' => 'p7b',
      'application/x-pkcs7-certreqres' => 'p7r',
      'application/x-pkcs7-certreqresp' => 'p7r',
      'application/x-pkcs7-mime' => 'p7c',
      'application/x-pkcs7-signature' => 'p7a',
      'application/x-pointplus' => 'css',
      'application/x-portable-anymap' => 'pnm',
      'application/x-project' => 'mpt',
      'application/x-qpro' => 'wb1',
      'application/x-ra' => 'rar',
      'application/x-rar-compressed' => 'rar',
      'application/x-rtf' => 'rtf',
      'application/x-sdp' => 'sdp',
      'application/x-sea' => 'sea',
      'application/x-seelogo' => 'sl',
      'application/x-sh' => 'sh',
      'application/x-shar' => 'sh',
      'application/x-shockwave-flas' => 'swf',
      'application/x-shockwave-flash' => 'swf',
      'application/x-silverlight-app' => 'xap',
      'application/x-sit' => 'sit',
      'application/x-smaf' => 'mmf',
      'application/x-stuffi' => 'sit',
      'application/x-stuffit' => 'sit',
      'application/x-stuffitx' => 'sitx',
      'application/x-sv4cpio' => 'sv4cpio',
      'application/x-sv4crc' => 'sv4crc',
      'application/x-ta' => 'tar',
      'application/x-tar' => 'tar',
      'application/x-tcl' => 'tcl',
      'application/x-tex' => 'tex',
      'application/x-tex-tfm' => 'tfm',
      'application/x-troff' => 'avi',
      'application/x-troff-man' => 'man',
      'application/x-troff-me' => 'me',
      'application/x-troff-ms' => 'ms',
      'application/x-troff-msvide' => 'avi',
      'application/x-troff-msvideo' => 'avi',
      'application/x-ustar' => 'ustar',
      'application/x-visio' => 'vsd',
      'application/x-vndaudioexplosionmzz' => 'mzz',
      'application/x-vndls-xpix' => 'xpix',
      'application/x-vrml' => 'vrml',
      'application/x-win-bitmap' => 'bmp',
      'application/x-winhelp' => 'hlp',
      'application/x-wintalk' => 'wtk',
      'application/x-wpwin' => 'wpd',
      'application/x-wri' => 'wri',
      'application/x-x509-ca-cert' => 'crt',
      'application/x-x509-user-cert' => 'crt',
      'application/x-x509-user-cert' => 'pem',
      'application/x-xfig' => 'fig',
      'application/x-xl' => 'xls',
      'application/x-xpinstall' => 'xpi',
      'application/x-zi' => 'zip',
      'application/x-zip-compressed' => 'zip',
      'application/xcap-diff+xml' => 'xdf',
      'application/xenc+xml' => 'xenc',
      'application/xhtml+xm' => 'xhtml',
      'application/xhtml+xml' => 'xhtml',
      'application/xl' => 'xls',
      'application/xm' => 'xml',
      'application/xml' => 'xml',
      'application/xml-dtd' => 'dtd',
      'application/xop+xml' => 'xop',
      'application/xslt+xml' => 'xslt',
      'application/xspf+xml' => 'xspf',
      'application/xspf+xml' => 'xspf',
      'application/xv+xml' => 'mxml',
      'application/yang' => 'yang',
      'application/yin+xml' => 'yin',
      'application/zi' => 'zip',
      'application/zip' => 'zip',
      'audio/3gpp' => 'amr',
      'audio/3gpp2' => 'amr',
      'audio/ac' => 'ac3',
      'audio/adpcm' => 'adp',
      'audio/aiff' => 'aif',
      'audio/amr' => 'amr',
      'audio/AMR-WB' => 'awb',
      'audio/basic' => 'au',
      'audio/it' => 'it',
      'audio/m4a' => 'alac',
      'audio/makemyfunk' => 'pfunk',
      'audio/mid' => 'rmi',
      'audio/midi' => 'mid',
      'audio/mod' => 'mod',
      'audio/mp' => 'mp3',
      'audio/mp4' => 'm4a',
      'audio/mpeg' => 'mp3',
      'audio/mpeg3' => 'mp3',
      'audio/og' => 'ogg',
      'audio/ogg' => 'ogg',
      'audio/s3m' => 's3m',
      'audio/tsp-audio' => 'tsi',
      'audio/tsplayer' => 'tsp',
      'audio/vnddeceaudio' => 'uva',
      'audio/vnddigital-winds' => 'eol',
      'audio/vnddra' => 'dra',
      'audio/vnddts' => 'dts',
      'audio/vnddtshd' => 'dtshd',
      'audio/vndlucentvoice' => 'lvp',
      'audio/vndms-playreadymediapya' => 'pya',
      'audio/vndnueraecelp4800' => 'ecelp4800',
      'audio/vndnueraecelp7470' => 'ecelp7470',
      'audio/vndnueraecelp9600' => 'ecelp9600',
      'audio/vndqcelp' => 'qcp',
      'audio/vndrip' => 'rip',
      'audio/voc' => 'voc',
      'audio/voxware' => 'vox',
      'audio/wa' => 'wav',
      'audio/wav' => 'wav',
      'audio/wave' => 'wav',
      'audio/webm' => 'weba',
      'audio/x-aac' => 'aac',
      'audio/x-ac' => 'aac',
      'audio/x-adpcm' => 'snd',
      'audio/x-aiff' => 'aif',
      'audio/x-ape' => 'ape',
      'audio/x-au' => 'au',
      'audio/x-dss' => 'dss',
      'audio/x-dvf' => 'dvf',
      'audio/x-flac' => 'flac',
      'audio/x-flac' => 'flac',
      'audio/x-gsm' => 'gsm',
      'audio/x-jam' => 'jam',
      'audio/x-liveaudio' => 'lam',
      'audio/x-m4' => 'm4a',
      'audio/x-m4a' => 'm4a',
      'audio/x-mid' => 'mid',
      'audio/x-midi' => 'mid',
      'audio/x-mod' => 'mod',
      'audio/x-mpeg' => 'mp2',
      'audio/x-mpeg-3' => 'mp3',
      'audio/x-mpegurl' => 'm3u',
      'audio/x-mpequrl' => 'm3u',
      'audio/x-ms-wax' => 'wax',
      'audio/x-ms-wma' => 'wma',
      'audio/x-ms-wma' => 'wma',
      'audio/x-pn-realaudio' => 'ram',
      'audio/x-pn-realaudio-plugin' => 'rpm',
      'audio/x-psid' => 'sid',
      'audio/x-realaudio' => 'ra',
      'audio/x-twinvq' => 'vqf',
      'audio/x-vndaudioexplosionmjuicemediafile' => 'mjf',
      'audio/x-voc' => 'voc',
      'audio/x-wa' => 'wav',
      'audio/x-wav' => 'wav',
      'audio/x-wv' => 'wv',
      'audio/xm' => 'xm',
      'chemical/x-cdx' => 'cdx',
      'chemical/x-cif' => 'cif',
      'chemical/x-cmdf' => 'cmdf',
      'chemical/x-cml' => 'cml',
      'chemical/x-csml' => 'csml',
      'chemical/x-pdb' => 'pdb',
      'chemical/x-xyz' => 'xyz',
      'drawing/x-dwf (old)' => 'dwf',
      'i-world/i-vrml' => 'ivr',
      'image/bm' => 'bmp',
      'image/bmp' => 'bmp',
      'image/cd' => 'cdr',
      'image/cgm' => 'cgm',
      'image/fif' => 'fif',
      'image/g3fax' => 'g3',
      'image/gi' => 'gif',
      'image/gif' => 'gif',
      'image/jp' => 'jp2',
      'image/jpeg' => 'jpeg',
      'image/jutvision' => 'jut',
      'image/ktx' => 'ktx',
      'image/ms-bmp' => 'bmp',
      'image/pict' => 'pict',
      'image/pjpe' => 'jpeg',
      'image/pjpeg' => 'jpeg',
      'image/pn' => 'png',
      'image/png' => 'png',
      'image/prsbtif' => 'btif',
      'image/svg+xm' => 'photo',
      'image/svg+xml' => 'svg',
      'image/tiff' => 'tiff',
      'image/vasa' => 'mcf',
      'image/vnd.adobe.photosho' => 'psd',
      'image/vnd.microsoft.icon' => 'ico',
      'image/vndadobephotoshop' => 'psd',
      'image/vnddecegraphic' => 'uvi',
      'image/vnddjvu' => 'djvu',
      'image/vnddvbsubtitle' => 'sub',
      'image/vnddwg' => 'dwg',
      'image/vnddxf' => 'dxf',
      'image/vndfastbidsheet' => 'fbs',
      'image/vndfpx' => 'fpx',
      'image/vndfst' => 'fst',
      'image/vndfujixeroxedmics-mmr' => 'mmr',
      'image/vndfujixeroxedmics-rlc' => 'rlc',
      'image/vndms-modi' => 'mdi',
      'image/vndrn-realflash' => 'rf',
      'image/vndrn-realpix' => 'rp',
      'image/vndwapwbmp' => 'wbmp',
      'image/vndxiff' => 'xif',
      'image/webp' => 'webp',
      'image/x-bitmap' => 'bmp',
      'image/x-bm' => 'bmp',
      'image/x-cd' => 'cdr',
      'image/x-cmu-raster' => 'ras',
      'image/x-cmx' => 'cmx',
      'image/x-dwg' => 'dwg',
      'image/x-freehand' => 'fh',
      'image/x-ic' => 'ico',
      'image/x-icon' => 'ico',
      'image/x-jg' => 'art',
      'image/x-jps' => 'jps',
      'image/x-ms-bmp' => 'bmp',
      'image/x-pcx' => 'pcx',
      'image/x-pict' => 'pct',
      'image/x-pn' => 'png',
      'image/x-portable-anymap' => 'pnm',
      'image/x-portable-bitmap' => 'pbm',
      'image/x-portable-graymap' => 'pgm',
      'image/x-portable-pixmap' => 'ppm',
      'image/x-rgb' => 'rgb',
      'image/x-tiff' => 'tiff',
      'image/x-win-bitmap' => 'bmp',
      'image/x-windows-bm' => 'bmp',
      'image/x-windows-bmp' => 'bmp',
      'image/x-xbitma' => 'bmp',
      'image/x-xbitmap' => 'xbm',
      'image/x-xbm' => 'xbm',
      'image/x-xpixmap' => 'pm',
      'image/x-xwd' => 'xwd',
      'image/x-xwindowdump' => 'xwd',
      'image/xbm' => 'xbm',
      'image/xpm' => 'xpm',
      'message/rfc822' => 'eml',
      'model/mesh' => 'msh',
      'model/vndcollada+xml' => 'dae',
      'model/vnddwf' => 'dwf',
      'model/vndgdl' => 'gdl',
      'model/vndgtw' => 'gtw',
      'model/vndmts' => 'mts',
      'model/vndvtu' => 'vtu',
      'model/x-pov' => 'pov',
      'multipart/x-gzip' => 'gzip',
      'multipart/x-ustar' => 'ustar',
      'multipart/x-zi' => 'zip',
      'multipart/x-zip' => 'zip',
      'music/crescendo' => 'mid',
      'music/x-karaoke' => 'kar',
      'paleovu/x-pv' => 'pvu',
      'tar' => 'asp',
      'text/asp' => 'css',
      'text/calendar' => 'ics',
      'text/comma-separated-value' => 'csv',
      'text/css' => 'csv',
      'text/css' => 'css',
      'text/csv' => 'js',
      'text/ecmascript' => 'js',
      'text/htm' => 'html',
      'text/html' => 'html',
      'text/javascript' => 'mcf',
      'text/jso' => 'json',
      'text/mcf' => 'n3',
      'text/n3' => 'pas',
      'text/pascal' => 'dsc',
      'text/php' => 'php',
      'text/plain' => 'txt',
      'text/prslinestag' => 'wsc',
      'text/richtex' => 'rtx',
      'text/richtext' => 'rtx',
      'text/rtf' => 'rtf',
      'text/scriplet' => 'tsv',
      'text/sgml' => 'sgml',
      'text/srt' => 'srt',
      'text/tab-separated-values' => 't',
      'text/troff' => 'ttl',
      'text/turtle' => 'abc',
      'text/uri-list' => 'url',
      'text/vndabc' => 'curl',
      'text/vndcurl' => 'dcurl',
      'text/vndcurldcurl' => 'mcurl',
      'text/vndcurlmcurl' => 'scurl',
      'text/vndcurlscurl' => 'fly',
      'text/vndfly' => 'flx',
      'text/vndfmiflexstor' => 'gv',
      'text/vndgraphviz' => '3dml',
      'text/vndin3d3dml' => 'spot',
      'text/vndin3dspot' => 'rt',
      'text/vndrn-realtext' => 'jad',
      'text/vndsunj2meapp-descriptor' => 'wml',
      'text/vndwapwml' => 'wmls',
      'text/vndwapwmlscript' => 'htt',
      'text/vtt' => 'vtt',
      'text/webviewhtml' => 'aip',
      'text/x-asm' => 'asm',
      'text/x-audiosoft-intra' => 'htc',
      'text/x-c' => 'c',
      'text/x-comma-separated-value' => 'csv',
      'text/x-component' => 'lsx',
      'text/x-fortran' => 'f',
      'text/x-h' => 'h',
      'text/x-java-source' => 'jav',
      'text/x-la-asf' => 'm',
      'text/x-log' => 'log',
      'text/x-m' => 'hlb',
      'text/x-pascal' => 'p',
      'text/x-php' => 'php',
      'text/x-script' => 'csh',
      'text/x-scriptcsh' => 'el',
      'text/x-scriptelisp' => 'scm',
      'text/x-scriptguile' => 'ksh',
      'text/x-scriptksh' => 'lsp',
      'text/x-scriptlisp' => 'pl',
      'text/x-scriptperl' => 'pm',
      'text/x-scriptperl-module' => 'py',
      'text/x-scriptphyton' => 'rexx',
      'text/x-scriptrexx' => 'scm',
      'text/x-scriptscheme' => 'sh',
      'text/x-scriptsh' => 'tcl',
      'text/x-scripttcl' => 'tcsh',
      'text/x-scripttcsh' => 'zsh',
      'text/x-scriptzsh' => 'etx',
      'text/x-scriptzsh' => 'zsh',
      'text/x-server-parsed-html' => 'shtml',
      'text/x-setext' => 'uil',
      'text/x-sgml' => 'sgm',
      'text/x-speech' => 'talk',
      'text/x-uil' => 'vcs',
      'text/x-vcalendar' => 'vcf',
      'text/x-vcard' => 'xml',
      'text/x-vcard' => 'vcf',
      'text/xml' => '3gp',
      'text/xml' => 'xml',
      'text/xsl' => 'xsl',
      'video/3g' => '3gp',
      'video/3gpp' => '3g2',
      'video/3gpp' => '3gp',
      'video/3gpp2' => 'afl',
      'video/animaflex' => 'avi',
      'video/av' => 'avi',
      'video/avi' => 'avs',
      'video/avs-video' => 'dl',
      'video/dl' => 'fli',
      'video/fli' => 'gl',
      'video/gl' => 'h261',
      'video/h261' => 'h263',
      'video/h263' => 'h264',
      'video/h264' => 'jpgv',
      'video/jpeg' => 'jpm',
      'video/jpm' => 'mj2',
      'video/mj' => 'jp2',
      'video/mj2' => 'avi',
      'video/mp' => 'mp4',
      'video/mp4' => 'mp4',
      'video/mpeg' => 'mpeg',
      'video/msvide' => 'avi',
      'video/msvideo' => 'ogv',
      'video/og' => 'ogg',
      'video/ogg' => 'vdo',
      'video/quicktim' => 'mov',
      'video/quicktime' => 'mov',
      'video/vdo' => 'uvh',
      'video/vnd.rn-realvideo' => 'rv',
      'video/vnddecehd' => 'uvm',
      'video/vnddecemobile' => 'uvp',
      'video/vnddecepd' => 'uvs',
      'video/vnddecesd' => 'uvv',
      'video/vnddecevideo' => 'fvt',
      'video/vndfvt' => 'mxu',
      'video/vndmpegurl' => 'pyv',
      'video/vndms-playreadymediapyv' => 'rv',
      'video/vndrn-realvideo' => 'uvu',
      'video/vnduvvump4' => 'vos',
      'video/vosaic' => 'webm',
      'video/webm' => 'xdr',
      'video/webm' => 'webm',
      'video/x-amt-demorun' => 'xsr',
      'video/x-amt-showrun' => 'fmf',
      'video/x-atomic3d-feature' => 'dl',
      'video/x-dl' => 'f4v',
      'video/x-dv' => 'dv',
      'video/x-f4' => 'f4v',
      'video/x-f4v' => 'fli',
      'video/x-fl' => 'flv',
      'video/x-fli' => 'flv',
      'video/x-flv' => 'gl',
      'video/x-gl' => 'isu',
      'video/x-isvideo' => 'm4v',
      'video/x-m4v' => 'mjpg',
      'video/x-motion-jpeg' => 'mp2',
      'video/x-mpeg' => 'mp2',
      'video/x-mpeq2a' => 'asx',
      'video/x-ms-asf' => 'mwv',
      'video/x-ms-asf' => 'wmv',
      'video/x-ms-asf-plugin' => 'wm',
      'video/x-ms-wm' => 'wmv',
      'video/x-ms-wmv' => 'wmx',
      'video/x-ms-wmv' => 'wmv',
      'video/x-ms-wmx' => 'wvx',
      'video/x-ms-wvx' => 'avi',
      'video/x-msvide' => 'avi',
      'video/x-msvideo' => 'qtc',
      'video/x-qtc' => 'scm',
      'video/x-scm' => 'wmf',
      'video/x-sgi-movi' => 'movie',
      'video/x-sgi-movie' => 'movie',
      'windows/metafile' => 'mime',
      'www/mime' => 'ice',
      'x-conference/x-cooltalk' => 'svr',
      'x-music/x-midi' => 'mid',
      'x-world/x-svr' => 'vrt',
      'x-world/x-vrt' => 'xgz',
      'xgl/drawing' => 'xmz',
      'zz-application/zz-winassoc-cdr' => 'cdr',
    ];

    $accdb = [
      'accdb',
      'mdb',
    ];

    $archive = [
      '7z',
      'ace',
      'arc',
      'arj',
      'dmg',
      'gz',
      'iso',
      'lzh',
      'pkg',
      'rar',
      'sit',
      'tgz',
      'tar',
      'z',
    ];

    $audio = [
      'aif',
      'aiff',
      'aac',
      'alac',
      'amr',
      'ape',
      'au',
      'awb',
      'dct',
      'dss',
      'dvf',
      'dv',
      'flac',
      'gsm',
      'm4a',
      'm4p',
      'mid',
      'midi',
      'mmf',
      'mp3',
      'oga',
      'ra',
      'rm',
      'wav',
      'wma',
      'wv',
      'ram',
      'rpm',
    ];

    $calendar = [
      'ical',
      'icalendar',
      'ics',
      'ifb',
      'vcs',
    ];

    $certificate = [
      'p12',
      'p7a',
      'p7b',
      'p7c',
      'p7r',
      'p7s',
      'p10',
      'cert',
    ];

    $code = [
      'abap',
      'ada',
      'adp',
      'ahk',
      'aab',
      'as',
      'as3',
      'asc',
      'ascx',
      'asm',
      'asp',
      'awk',
      'bash',
      'bash_login',
      'bash_logout',
      'bash_profile',
      'bashrc',
      'bat',
      'bib',
      'bsh',
      'build',
      'builder',
      'c',
      'cbl',
      'c++',
      'capfile',
      'cc',
      'cfc',
      'cfm',
      'cfml',
      'cl',
      'clj',
      'cls',
      'cmake',
      'cmd',
      'coffee',
      'config',
      'cpp',
      'cpt',
      'cpy',
      'cs',
      'cshtml',
      'cson',
      'csproj',
      'css',
      'ctp',
      'cxx',
      'd',
      'ddl',
      'di',
      'disco',
      'dml',
      'dtd',
      'dtml',
      'el',
      'emakefile',
      'env',
      'erb',
      'erl',
      'f',
      'f90',
      'f95',
      'fs',
      'fsi',
      'fsscript',
      'fsx',
      'gemfile',
      'gemspec',
      'gitconfig',
      'go',
      'groovy',
      'gvy',
      'h',
      'h++',
      'haml',
      'handlebars',
      'html',
      'hbs',
      'hcp',
      'hh',
      'hpp',
      'hrl',
      'hs',
      'htc',
      'hxx',
      'idl',
      'iim',
      'inc',
      'inf',
      'ini',
      'inl',
      'ipp',
      'irbrc',
      'jade',
      'jav',
      'java',
      'js',
      'json',
      'jsp',
      'jsproj',
      'jsx',
      'l',
      'less',
      'lhs',
      'lisp',
      'log',
      'lst',
      'ltx',
      'lua',
      'm',
      'mak',
      'make',
      'manifest',
      'master',
      'md',
      'markdn',
      'markdown',
      'mdown',
      'mkdn',
      'ml',
      'mli',
      'mll',
      'mly',
      'mm',
      'mud',
      'nfo',
      'opml',
      'osascript',
      'p',
      'pas',
      'patch',
      'php',
      'php2',
      'php3',
      'php4',
      'php5',
      'phtml',
      'pl',
      'pm',
      'pod',
      'pp',
      'profile',
      'ps1',
      'ps1xml',
      'psd1',
      'psm1',
      'pss',
      'pt',
      'py',
      'pyw',
      'r',
      'rake',
      'rb',
      'rbx',
      'rc',
      'rdf',
      're',
      'reg',
      'rest',
      'resw',
      'resx',
      'rhtml',
      'rjs',
      'rprofile',
      'rpy',
      'rss',
      'rst',
      'ruby',
      'rxml',
      's',
      'sass',
      'scala',
      'scm',
      'sconscript',
      'sconstruct',
      'script',
      'scss',
      'sgml',
      'sh',
      'shtml',
      'sml',
      'svn-base',
      'swift',
      'sql',
      'sty',
      'tcl',
      'tex',
      'textile',
      'tld',
      'tli',
      'tmpl',
      'tpl',
      'vb',
      'vi',
      'vim',
      'vmg',
      'web',
      'webpart',
      'wsp',
      'wsdl',
      'xhtml',
      'xoml',
      'xsd',
      'xslt',
      'yaml',
      'yaws',
      'yml',
      'zsh',
    ];

    $contact = [
      'vcf',
    ];

    $csv = [
      'csv',
    ];

    $docx = [
      'doc',
      'docm',
      'docx',
      'docb',
      'wp',
    ];

    $dotx = [
      'dot',
      'dotm',
      'dotx',
    ];

    $email = [
      'eml',
      'msg',
      'ost',
      'pst',
    ];

    $exe = [
      'application',
      'appref-ms',
      'apk',
      'app',
      'appx',
      'exe',
      'ipa',
      'msi',
      'xap',
    ];

    $font = [
      'ttf',
      'otf',
      'woff',
    ];

    $fluid = [
      'b',
      'fluid',
    ];

    $html = [
      'b',
      'fluid',
    ];

    $link = [
      'lnk',
      'link',
      'url',
      'website',
      'webloc',
    ];

    $officescript = ['osts'];

    $splist = ['listitem'];

    $model = [
      '3ds',
      '3mf',
      'blend',
      'cool',
      'dae',
      'df',
      'dwfx',
      'dwg',
      'dxf',
      'fbx',
      'glb',
      'gltf',
      'holo',
      'layer',
      'layout',
      'max',
      'mcworld',
      'mtl',
      'obj',
      'off',
      'ply',
      'skp',
      'stp',
      'stl',
      't',
      'thl',
      'x',
    ];

    $mpp = ['mpp'];

    $mpt = ['mpt'];

    $one = [
      'note',
      'one',
    ];

    $onetoc = [
      'ms-one-stub',
      'onetoc',
      'onetoc2',
      'onepkg',
    ];

    $pdf = ['pdf'];

    $photo = [
      'arw',
      'bmp',
      'cr2',
      'crw',
      'dic',
      'dicm',
      'dcm',
      'dcm30',
      'dcr',
      'dds',
      'dib',
      'dng',
      'erf',
      'gif',
      'heic',
      'heif',
      'ico',
      'jfi',
      'jfif',
      'jif',
      'jpe',
      'jpeg',
      'jpg',
      'jxr',
      'kdc',
      'mrw',
      'nef',
      'orf',
      'pct',
      'pict',
      'png',
      'pns',
      'psb',
      'psd',
      'raw',
      'tga',
      'tif',
      'tiff',
      'wdp',
    ];

    $potx = [
      'pot',
      'potm',
      'potx',
    ];

    $powerbi = [
      'pbids',
      'pbix',
    ];

    $ppsx = [
      'pps',
      'ppsm',
      'ppsx',
    ];

    $pptx = [
      'ppt',
      'pptm',
      'pptx',
      'sldx',
      'sldm',
    ];

    $presentation = [
      'odp',
      'gslides',
      'key',
    ];

    $pub = ['pub'];

    $spo = [
      'aspx',
      'classifier',
    ];

    $spreadsheet = [
      'odc',
      'ods',
      'gsheet',
      'numbers',
      'tsv',
    ];

    $rtf = [
      'epub',
      'gdoc',
      'odt',
      'rtf',
      'rtx',
      'wri',
      'pages',
    ];

    $speech = [
      'talk',
    ];

    $sysfile = [
      'bak',
      'bin',
      'cab',
      'cache',
      'cat',
      'cer',
      'class',
      'dat',
      'db',
      'dbg',
      'dl_',
      'dll',
      'ithmb',
      'jar',
      'kb',
      'ldt',
      'lrprev',
      'pkpass',
      'ppa',
      'ppam',
      'pdb',
      'rom',
      'thm',
      'thmx',
      'vsl',
      'xla',
      'xlam',
      'xlb',
      'xll',
    ];

    $txt = [
      'dif',
      'diff',
      'readme',
      'out',
      'plist',
      'properties',
      'text',
      'txt',
    ];

    $vector = [
      'ai',
      'ait',
      'cvs',
      'dgn',
      'gdraw',
      'pd',
      'emf',
      'eps',
      'fig',
      'ind',
      'indd',
      'indl',
      'indt',
      'indb',
      'ps',
      'svg',
      'svgz',
      'wmf',
      'oxps',
      'xps',
      'xd',
      'sketch',
    ];

    $video = [
      '3g2',
      '3gp',
      '3gp2',
      '3gpp',
      'asf',
      'avi',
      'dvr-ms',
      'flv',
      'm1v',
      'm4v',
      'mkv',
      'mod',
      'mov',
      'mm4p',
      'mp2',
      'mp2v',
      'mp4',
      'mp4v',
      'mpa',
      'mpe',
      'mpeg',
      'mpg',
      'mpv',
      'mpv2',
      'mts',
      'ogg',
      'qt',
      'swf',
      'ts',
      'vob',
      'webm',
      'wlmp',
      'wm',
      'wmv',
      'wmx',
    ];

    $vsdx = [
      'vdx',
      'vsd',
      'vsdm',
      'vsdx',
      'vsw',
      'vdw',
    ];

    $vssx = [
      'vss',
      'vssm',
      'vssx',
    ];

    $vstx = [
      'vst',
      'vstm',
      'vstx',
      'vsx',
    ];

    $whiteboard = ['whiteboard'];

    $xlsx = [
      'xlc',
      'xls',
      'xlsb',
      'xlsm',
      'xlsx',
      'xlw',
    ];

    $xltx = [
      'xlt',
      'xltm',
      'xltx',
    ];

    $xml = [
      'xaml',
      'xml',
      'xsl',
      'smil',
    ];

    $xsn = ['xsn'];

    $zip = ['zip'];

    if (in_array($extensionType[$mimeType], $accdb)) {
      return $mimeType = 'accdb';
    }

    if (in_array($extensionType[$mimeType], $archive)) {
      return $mimeType = 'archive';
    }

    if (in_array($extensionType[$mimeType], $audio)) {
      return $mimeType = 'audio';
    }

    if (in_array($extensionType[$mimeType], $calendar)) {
      return $mimeType = 'calendar';
    }

    if (in_array($extensionType[$mimeType], $certificate)) {
      return $mimeType = 'certificate';
    }

    if (in_array($extensionType[$mimeType], $code)) {
      return $mimeType = 'code';
    }

    if (in_array($extensionType[$mimeType], $contact)) {
      return $mimeType = 'contact';
    }

    if (in_array($extensionType[$mimeType], $csv)) {
      return $mimeType = 'csv';
    }

    if (in_array($extensionType[$mimeType], $docx)) {
      return $mimeType = 'docx';
    }

    if (in_array($extensionType[$mimeType], $dotx)) {
      return $mimeType = 'dotx';
    }

    if (in_array($extensionType[$mimeType], $email)) {
      return $mimeType = 'email';
    }

    if (in_array($extensionType[$mimeType], $exe)) {
      return $mimeType = 'exe';
    }

    if (in_array($extensionType[$mimeType], $font)) {
      return $mimeType = 'font';
    }

    if (in_array($extensionType[$mimeType], $fluid)) {
      return $mimeType = 'fluid';
    }

    if (in_array($extensionType[$mimeType], $html)) {
      return $mimeType = 'html';
    }

    if (in_array($extensionType[$mimeType], $link)) {
      return $mimeType = 'link';
    }

    if (in_array($extensionType[$mimeType], $officescript)) {
      return $mimeType = 'officescript';
    }

    if (in_array($extensionType[$mimeType], $splist)) {
      return $mimeType = 'splist';
    }

    if (in_array($extensionType[$mimeType], $model)) {
      return $mimeType = 'model';
    }

    if (in_array($extensionType[$mimeType], $mpp)) {
      return $mimeType = 'mpp';
    }

    if (in_array($extensionType[$mimeType], $mpt)) {
      return $mimeType = 'mpt';
    }

    if (in_array($extensionType[$mimeType], $one)) {
      return $mimeType = 'one';
    }

    if (in_array($extensionType[$mimeType], $onetoc)) {
      return $mimeType = 'onetoc';
    }

    if (in_array($extensionType[$mimeType], $pdf)) {
      return $mimeType = 'pdf';
    }

    if (in_array($extensionType[$mimeType], $photo)) {
      return $mimeType = 'photo';
    }

    if (in_array($extensionType[$mimeType], $potx)) {
      return $mimeType = 'potx';
    }

    if (in_array($extensionType[$mimeType], $powerbi)) {
      return $mimeType = 'powerbi';
    }

    if (in_array($extensionType[$mimeType], $ppsx)) {
      return $mimeType = 'ppsx';
    }

    if (in_array($extensionType[$mimeType], $pptx)) {
      return $mimeType = 'pptx';
    }

    if (in_array($extensionType[$mimeType], $presentation)) {
      return $mimeType = 'presentation';
    }

    if (in_array($extensionType[$mimeType], $pub)) {
      return $mimeType = 'pub';
    }

    if (in_array($extensionType[$mimeType], $spo)) {
      return $mimeType = 'spo';
    }

    if (in_array($extensionType[$mimeType], $spreadsheet)) {
      return $mimeType = 'spreadsheet';
    }

    if (in_array($extensionType[$mimeType], $rtf)) {
      return $mimeType = 'rtf';
    }

    if (in_array($extensionType[$mimeType], $speech)) {
      return $mimeType = 'speech';
    }

    if (in_array($extensionType[$mimeType], $sysfile)) {
      return $mimeType = 'sysfile';
    }

    if (in_array($extensionType[$mimeType], $txt)) {
      return $mimeType = 'txt';
    }

    if (in_array($extensionType[$mimeType], $vector)) {
      return $mimeType = 'vector';
    }

    if (in_array($extensionType[$mimeType], $video)) {
      return $mimeType = 'video';
    }

    if (in_array($extensionType[$mimeType], $vsdx)) {
      return $mimeType = 'vsdx';
    }

    if (in_array($extensionType[$mimeType], $vssx)) {
      return $mimeType = 'vssx';
    }

    if (in_array($extensionType[$mimeType], $vstx)) {
      return $mimeType = 'vstx';
    }

    if (in_array($extensionType[$mimeType], $whiteboard)) {
      return $mimeType = 'whiteboard';
    }

    if (in_array($extensionType[$mimeType], $xlsx)) {
      return $mimeType = 'xlsx';
    }

    if (in_array($extensionType[$mimeType], $xltx)) {
      return $mimeType = 'xltx';
    }

    if (in_array($extensionType[$mimeType], $xml)) {
      return $mimeType = 'xml';
    }

    if (in_array($extensionType[$mimeType], $xsn)) {
      return $mimeType = 'xsn';
    }

    if (in_array($extensionType[$mimeType], $zip)) {
      return $mimeType = 'zip';
    }

    return 'txt';
  }

}
